# swaggin_fh
a very shotty python library for handling .swaggin files. It should also be noted that these files have almost no intrinsic use, and are purely to be that extra bit swaggin


## Installation
With [PyPI](https://pypi.org/):
```bash
pip install swagginfh
```
Or from GitHub
```bash
https://github.com/stripeysweatercat/swaggin-fh
```

## Contributing
hm. Why would you want to contribute to this lmfao. Pull requests and bug reports are welcome :)

## License
This module is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT)